EventTypes class

Event type constants matching the Unilitix backend schema.

Constructors

EventTypes()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

crash → const String
custom → const String
rageTap → const String
scroll → const String
sessionEnd → const String
sessionStart → const String
tap → const String